@@ -2,7 +2,7 @@ package Test2::Mock;
 use strict;
 use warnings;
 
-our $VERSION = '0.000055';
+our $VERSION = '0.000072';
 
 use Carp qw/croak confess/;
 our @CARP_NOT = (__PACKAGE__);
@@ -155,13 +155,15 @@ sub autoload {
 
     croak "Class '$class' already has an AUTOLOAD"
         if $stash->{AUTOLOAD} && *{$stash->{AUTOLOAD}}{CODE};
+    croak "Class '$class' already has an can"
+        if $stash->{can} && *{$stash->{can}}{CODE};
 
     # Weaken this reference so that AUTOLOAD does not prevent its own
     # destruction.
     weaken(my $c = $self);
 
     my ($file, $line) = (__FILE__, __LINE__ + 3);
-    my $sub = eval <<EOT || die $@;
+    my $sub = eval <<EOT || die "Failed generating AUTOLOAD sub: $@";
 package $class;
 #line $line "$file (Generated AUTOLOAD)"
 our \$AUTOLOAD;
@@ -183,6 +185,24 @@ our \$AUTOLOAD;
 EOT
 
     $self->add(AUTOLOAD => $sub);
+
+    $line = __LINE__ + 3;
+    $sub = eval <<EOT || die "Failed generating can method: $@";
+package $class;
+#line $line "$file (Generated can)"
+    sub {
+        my (\$self, \$meth) = \@_;
+        if (\$self->SUPER::can(\$meth)) {
+            return \$self->SUPER::can(\$meth);
+        }
+        elsif (exists \$self->{\$meth}) {
+            return sub { shift->\$meth(\@_) };
+        }
+        return undef;
+    }
+EOT
+
+    $self->add(can => $sub);
 }
 
 sub before {
@@ -283,10 +303,14 @@ sub _parse_inject {
 
     my ($is, $field, $val);
 
-    if (!ref($arg)) {
-        $is    = $arg if $arg =~ m/^(rw|ro|wo)$/;
+    if(defined($arg) && !ref($arg) && $arg =~ m/^(rw|ro|wo)$/) {
+        $is    = $arg;
         $field = $param;
     }
+    elsif (!ref($arg)) {
+        $val = $arg;
+        $is  = 'val';
+    }
     elsif (reftype($arg) eq 'HASH') {
         $field = delete $arg->{field} || $param;
 
@@ -300,9 +324,9 @@ sub _parse_inject {
         croak "The following keys are not valid when defining a mocked sub with a hashref: " . join(", " => keys %$arg)
             if keys %$arg;
     }
-
-    confess "'$arg' is not a valid argument when defining a mocked sub"
-        unless $is;
+    else {
+        confess "'$arg' is not a valid argument when defining a mocked sub";
+    }
 
     my $sub;
     if ($is eq 'rw') {
